# plot_context_manager

![GitHub repo size](https://img.shields.io/github/issues/AlbertFarkhutdinov/plot_context_manager)
![PyPI version](https://img.shields.io/pypi/v/plot-context-manager)
![GitHub contributors](https://img.shields.io/github/contributors/AlbertFarkhutdinov/plot_context_manager)
![GitHub stars](https://img.shields.io/github/stars/AlbertFarkhutdinov/plot_context_manager)
![GitHub forks](https://img.shields.io/github/forks/AlbertFarkhutdinov/plot_context_manager)
![GitHub licence](https://img.shields.io/github/license/AlbertFarkhutdinov/plot_context_manager)

`plot_context_manager` is a package to work with plots as with context managers.

## Prerequisites

Before you begin, ensure you have installed the latest version of Python.

## Installing `plot_context_manager`

To install `plot_context_manager`, follow these steps:

Linux and macOS:
```
pip3 install plot-context-manager
```

Windows:
```
pip install plot-context-manager
```
## Using `plot_context_manager`

There are will be examples of how to use `plot_context_manager`.

## Contributing to `plot_context_manager`
To contribute to `plot_context_manager`, follow these steps:

1. Fork this repository.
2. Create a branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively see the GitHub documentation on [creating a pull request](https://help.github.com/en/github/collaborating-with-issues-and-pull-requests/creating-a-pull-request).

## Contributors

* [@AlbertFarkhutdinov](https://github.com/AlbertFarkhutdinov) 

## Contact

If you want to contact me you can reach me at `albertfarhutdinov@gmail.com`.

## License
This project uses the following license: [MIT License](https://github.com/AlbertFarkhutdinov/plot_context_manager/blob/main/LICENSE).